package net.h34t.filemure.controller

import io.javalin.http.Context
import net.h34t.filemure.TemplateModifiers
import net.h34t.filemure.repository.SqliteRepository
import net.h34t.filemure.requireSession
import net.h34t.filemure.tempolin
import net.h34t.filemure.tpl.Frame
import net.h34t.filemure.tpl.Overview
import java.time.format.DateTimeFormatter
import java.time.format.FormatStyle

class OverviewController(val modifiers: TemplateModifiers, val repository: SqliteRepository) {

    private val htmlDtf = DateTimeFormatter.ofLocalizedDateTime(FormatStyle.SHORT, FormatStyle.SHORT)

    fun overview(ctx: Context) {
        val session = ctx.requireSession()

        val limboFileCount = repository.getLimboFileCount(accountId = session.id)

        val documents = repository.getDocuments(accountId = session.id)

        ctx.tempolin(
            Frame(
                modifiers = modifiers,
                title = "Overview",
                isTarget = true,
                content = Overview(
                    modifiers = modifiers,
                    limboFileCount = limboFileCount.toString(),
                    document = {
                        documents.map { document ->
                            DocumentBlock(
                                extId = document.extId.value,
                                referenceDate = htmlDtf.format(document.referenceDate),
                                title = document.title.ifBlank { "untitled" },
                            )
                        }.asSequence()
                    }
                )
            )
        )
    }
}